==> haskell-wai-middleware-static-0.9.3-169-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-middleware-static
version:              0.9.3
visibility:           public
id:                   wai-middleware-static-0.9.3-FjqqQQhQpmJ3OoIsumCb2b
key:                  wai-middleware-static-0.9.3-FjqqQQhQpmJ3OoIsumCb2b
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  bcb1464a961320cd361452b9fee4ec31
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.3-FjqqQQhQpmJ3OoIsumCb2b
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-20IAHeb4Utp2ZGQEDCbDdS
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-26hcqnq6SoBK1r66aAF0ds directory-1.3.7.1
    expiring-cache-map-0.0.6.1-8w9GhPMTM1xGu9odfE6BHy filepath-1.4.2.2
    http-types-0.12.4-8EgajALSM5xB8GFkN9ClFd
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh text-2.0.2 time-1.12.2
    wai-3.2.4-6pK67aQEgpK6NKWKR3cfH5

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-middleware-static-0.9.3-170-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-middleware-static
version:              0.9.3
visibility:           public
id:                   wai-middleware-static-0.9.3-KvBvZi7UpJk6Ma1UTwtYRg
key:                  wai-middleware-static-0.9.3-KvBvZi7UpJk6Ma1UTwtYRg
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  829151a5ec1bad47f7e23ca65a341f32
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.3-KvBvZi7UpJk6Ma1UTwtYRg
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-20IAHeb4Utp2ZGQEDCbDdS
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-26hcqnq6SoBK1r66aAF0ds directory-1.3.7.1
    expiring-cache-map-0.0.6.1-8w9GhPMTM1xGu9odfE6BHy filepath-1.4.2.2
    http-types-0.12.4-8EgajALSM5xB8GFkN9ClFd
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh text-2.0.2 time-1.12.2
    wai-3.2.4-6pK67aQEgpK6NKWKR3cfH5

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
